### Publications




#### **2022:**

###### Portela T.T., Carvalho J.T., Bogorny V. **HIPERMovelets: high-performance movelet extraction for trajectory classification**. International Journal of Geographical Information Science, 2021. DOI: https://doi.org/10.1080/13658816.2021.2018593




#### **2021:**

###### Portela T.T., da Silva C.L., Carvalho J.T., Bogorny V. **Fast Movelet Extraction and Dimensionality Reduction for Robust Multiple Aspect Trajectory Classification**. In: Britto A., Valdivia Delgado K. (eds) Intelligent Systems. BRACIS 2021. Lecture Notes in Computer Science, vol 13073. Springer, Cham. DOI: https://doi.org/10.1007/978-3-030-91702-9_31 

\[ [description](/method/SUPERMovelets) \] \[ [GitHub](/method/SUPERMovelets) \] \[ Datasets: \]




#### **2020:**

###### May Petry L., Leite Da Silva C., Esuli A., Renso C., Bogorny V. **MARC: a robust method for multiple-aspect trajectory classification via space, time, and semantic embeddings**. International Journal of Geographical Information Science, 2020, 34:7, 1428-1450. DOI: https://doi.org/10.1080/13658816.2019.1707835
 [MARC](/method/MARC)



###### Vicenzi F., May Petry L., Leite da Silva C., Alvares L.O., Bogorny V. **Exploring frequency-based approaches for efficient trajectory classification**. In Proceedings of the 35th Annual ACM Symposium on Applied Computing (SAC '20), 2020. Association for Computing Machinery, New York, NY, USA, 624–631. DOI: https://doi.org/10.1145/3341105.3374045
[POI-F](/method/POIF)


###### Ferrero, C. A., Petry, L. M., Alvares, L. O., Silva, C. L., Zalewski, W., Bogorny, V. **MasterMovelets: Discovering Heterogeneous Movelets for Multiple Aspect Trajectory Classification**. Data Mining and Knowledge Discovery, 2020, 34(3), 652-680. DOI: https://doi.org/10.1007/s10618-020-00676-x
[MASTERMovelets](/method/MASTERMovelets)



##### **2018:**
###### Ferrero, C. A., Alvares, L. O., Zalewski, W., Bogorny, V. **MOVELETS: Exploring Relevant Subtrajectories for Robust Trajectory Classification**. In Proceedings of the 33rd Annual ACM Symposium on Applied Computing (SAC '18). Association for Computing Machinery, New York, NY, USA, 849–856. DOI: https://doi.org/10.1145/3167132.3167225
[Movelets](/method/Movelets)


##### **Before:**

###### Xiao, Z., Wang, Y., Fu, K., & Wu, F. (2017). Identifying different transportation modes from trajectory data using tree-based ensemble classifiers. ISPRS International Journal of Geo-Information, 6(2), 57. DOI: https://doi.org/10.3390/ijgi6020057
[Xiao](/method/Xiao)

###### Zheng, Y., Chen, Y., Li, Q., Xie, X., & Ma, W. Y. (2010). Understanding transportation modes based on GPS data for web applications. ACM Transactions on the Web (TWEB), 4(1), 1-36. DOI: https://doi.org/10.1145/1658373.1658374
[Zheng](/method/Zheng)

###### Dodge, S., Weibel, R., & Forootan, E. (2009). Revealing the physics of movement: Comparing the similarity of movement characteristics of different types of moving objects. Computers, Environment and Urban Systems, 33(6), 419-434. DOI: https://doi.org/10.1016/j.compenvurbsys.2009.07.008
[Dodge](/method/Dodge)



